@@ -2,8 +2,8 @@ pub mod smsc;
 pub mod smsc_config;
 pub mod smsc_logic;
 
-pub use crate::pdu::data::bind_data::BindData;
-pub use crate::pdu::data::bind_resp_data::BindRespData;
+pub use smpp_pdu::pdu::data::bind_data::BindData;
+pub use smpp_pdu::pdu::data::bind_resp_data::BindRespData;
 pub use smsc::{run, Smsc};
 pub use smsc_config::SmscConfig;
 pub use smsc_logic::{BindError, SmscLogic, SubmitSmError};
